# GenerateApiKeyRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**apikey_id** | **str** | The identifier to use for the api key, which will become the final component of the api key&#39;s resource name. This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


